@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2012 Aurimas Cernius
+ * Copyright (C) 2011-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -69,12 +69,6 @@
 
 namespace gnote {
 
-  const int ActionManager::APP_ACTION_NEW = 1;
-  const int ActionManager::APP_ACTION_MANAGE = 2;
-  const int ActionManager::APP_ACTION_HELP = 3;
-  const int ActionManager::APP_ACTION_LAST = 4;
-
-
   ActionManager::ActionManager()
     : m_ui(Gtk::UIManager::create())
     , m_main_window_actions(Gtk::ActionGroup::create("MainWindow"))
@@ -245,9 +239,11 @@ namespace gnote {
     return Glib::RefPtr<Gio::SimpleAction>();
   }
 
-  void ActionManager::add_app_action(const std::string & name)
+  Glib::RefPtr<Gio::SimpleAction> ActionManager::add_app_action(const std::string & name)
   {
-    m_app_actions.push_back(Gio::SimpleAction::create(name));
+    Glib::RefPtr<Gio::SimpleAction> action = Gio::SimpleAction::create(name);
+    m_app_actions.push_back(action);
+    return action;
   }
 
   void ActionManager::add_app_menu_item(int section, int order, const std::string & label,
@@ -316,4 +312,71 @@ namespace gnote {
     return section;
   }
 
+  void ActionManager::add_main_window_search_action(const Glib::RefPtr<Gtk::Action> & action, int order)
+  {
+    add_main_window_action(m_main_window_search_actions, action, order);
+    signal_main_window_search_actions_changed();
+  }
+
+  void ActionManager::remove_main_window_search_action(const std::string & name)
+  {
+    remove_main_window_action(m_main_window_search_actions, name);
+    signal_main_window_search_actions_changed();
+  }
+
+  std::vector<Glib::RefPtr<Gtk::Action> > ActionManager::get_main_window_search_actions()
+  {
+    return get_main_window_actions(m_main_window_search_actions);
+  }
+
+  void ActionManager::add_main_window_note_action(const Glib::RefPtr<Gtk::Action> & action, int order)
+  {
+    add_main_window_action(m_main_window_note_actions, action, order);
+    signal_main_window_note_actions_changed();
+  }
+
+  void ActionManager::remove_main_window_note_action(const std::string & name)
+  {
+    remove_main_window_action(m_main_window_note_actions, name);
+    signal_main_window_note_actions_changed();
+  }
+
+  std::vector<Glib::RefPtr<Gtk::Action> > ActionManager::get_main_window_note_actions()
+  {
+    return get_main_window_actions(m_main_window_note_actions);
+  }
+
+  void ActionManager::add_main_window_action(std::map<int, Glib::RefPtr<Gtk::Action> > & actions,
+                                             const Glib::RefPtr<Gtk::Action> & action, int order)
+  {
+    std::map<int, Glib::RefPtr<Gtk::Action> >::iterator iter = actions.find(order);
+    while(iter != actions.end()) {
+      iter = actions.find(++order);
+    }
+    actions[order] = action;
+  }
+
+  void ActionManager::remove_main_window_action(std::map<int, Glib::RefPtr<Gtk::Action> > & actions,
+    const std::string & name)
+  {
+    for(std::map<int, Glib::RefPtr<Gtk::Action> >::iterator iter = actions.begin();
+        iter != actions.end(); ++iter) {
+      if(iter->second->get_name() == name) {
+        actions.erase(iter);
+        break;
+      }
+    }
+  }
+
+  std::vector<Glib::RefPtr<Gtk::Action> > ActionManager::get_main_window_actions(
+    std::map<int, Glib::RefPtr<Gtk::Action> > & actions)
+  {
+    std::vector<Glib::RefPtr<Gtk::Action> > res;
+    for(std::map<int, Glib::RefPtr<Gtk::Action> >::iterator iter = actions.begin();
+        iter != actions.end(); ++iter) {
+      res.push_back(iter->second);
+    }
+    return res;
+  }
+
 }
