@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -37,13 +37,12 @@
 #include <gtkmm/button.h>
 #include <gtkmm/stock.h>
 
-#include "gnote.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
 #include "noterenamedialog.hpp"
 #include "notetag.hpp"
 #include "notewindow.hpp"
-#include "tagmanager.hpp"
+#include "itagmanager.hpp"
 #include "utils.hpp"
 #include "debug.hpp"
 #include "notebooks/notebookmanager.hpp"
@@ -119,7 +118,7 @@ namespace gnote {
                               _("An error occurred while saving your notes. "
                                 "Please check that you have sufficient disk "
                                 "space, and that you have appropriate rights "
-                                "on ~/.gnote. Error details can be found in "
+                                "on ~/.local/share/gnote. Error details can be found in "
                                 "~/.gnote.log."));
       dialog.run();
     }
@@ -873,7 +872,7 @@ namespace gnote {
             parse_tags (doc2->children, tag_strings);
             for(std::list<std::string>::const_iterator iter = tag_strings.begin();
                 iter != tag_strings.end(); ++iter) {
-              Tag::Ptr tag = TagManager::obj().get_or_create_tag(*iter);
+              Tag::Ptr tag = ITagManager::obj().get_or_create_tag(*iter);
               new_tags.push_back(tag);
             }
             xmlFreeDoc(doc2);
@@ -1040,7 +1039,7 @@ namespace gnote {
       m_note_window_embedded = true;
     }
 
-    notebooks::NotebookManager::instance().active_notes_notebook()->add_note(shared_from_this());
+    notebooks::NotebookManager::obj().active_notes_notebook()->add_note(shared_from_this());
   }
 
   bool Note::is_special() const
@@ -1087,7 +1086,7 @@ namespace gnote {
       }
     }
     settings->set_string(Preferences::MENU_PINNED_NOTES, new_pinned);
-    notebooks::NotebookManager::instance().signal_note_pin_status_changed(*this, pinned);
+    notebooks::NotebookManager::obj().signal_note_pin_status_changed(*this, pinned);
   }
 
   void Note::get_tags(std::list<Tag::Ptr> & l) const
@@ -1115,6 +1114,10 @@ namespace gnote {
   const char *NoteArchiver::CURRENT_VERSION = "0.3";
 //  const char *NoteArchiver::DATE_TIME_FORMAT = "%Y-%m-%dT%T.@7f@%z"; //"yyyy-MM-ddTHH:mm:ss.fffffffzzz";
 
+  //instance
+  NoteArchiver NoteArchiver::s_obj;
+
+
   NoteData *NoteArchiver::read(const std::string & read_file, const std::string & uri)
   {
     return obj().read_file(read_file, uri);
@@ -1127,10 +1130,16 @@ namespace gnote {
     sharp::XmlReader xml(file);
     NoteData *data = _read(xml, uri, version);
     if(version != NoteArchiver::CURRENT_VERSION) {
-      // Note has old format, so rewrite it.  No need
-      // to reread, since we are not adding anything.
-      DBG_OUT("Updating note XML from %s to newest format...", version.c_str());
-      NoteArchiver::write(file, *data);
+      try {
+        // Note has old format, so rewrite it.  No need
+        // to reread, since we are not adding anything.
+        DBG_OUT("Updating note XML from %s to newest format...", version.c_str());
+        NoteArchiver::write(file, *data);
+      }
+      catch(sharp::Exception & e) {
+        // write failure, but not critical
+        ERR_OUT("Failed to update note format: %s", e.what());
+      }
     }
     return data;
   }
@@ -1203,7 +1212,7 @@ namespace gnote {
             Note::parse_tags(doc2->children, tag_strings);
             for(std::list<std::string>::const_iterator iter = tag_strings.begin();
                 iter != tag_strings.end(); ++iter) {
-              Tag::Ptr tag = TagManager::obj().get_or_create_tag(*iter);
+              Tag::Ptr tag = ITagManager::obj().get_or_create_tag(*iter);
               note->tags()[tag->normalized_name()] = tag;
             }
             xmlFreeDoc(doc2);
@@ -1241,13 +1250,13 @@ namespace gnote {
 
   void NoteArchiver::write_file(const std::string & _write_file, const NoteData & note)
   {
-    std::string tmp_file = _write_file + ".tmp";
-    // TODO Xml doc settings
-    sharp::XmlWriter xml(tmp_file); //, XmlEncoder::DocumentSettings);
-    write(xml, note);
-    xml.close ();
-
     try {
+      std::string tmp_file = _write_file + ".tmp";
+      // TODO Xml doc settings
+      sharp::XmlWriter xml(tmp_file); //, XmlEncoder::DocumentSettings);
+      write(xml, note);
+      xml.close();
+
       if (sharp::file_exists(_write_file)) {
         std::string backup_path = _write_file + "~";
         if (sharp::file_exists(backup_path)) {
