@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -36,21 +36,16 @@
 namespace gnote {
   class NoteManager;
 
-typedef utils::ForcedPresentWindow NoteRecentChangesParent;
-
 class NoteRecentChanges
-  : public NoteRecentChangesParent
-  , public utils::EmbeddableWidgetHost
+  : public MainWindow
 {
 public:
-  static NoteRecentChanges *get_owning(Gtk::Widget & widget);
-
   NoteRecentChanges(NoteManager& m);
   virtual ~NoteRecentChanges();
-  void set_search_text(const std::string & value);
-  void present_note(const Note::Ptr & note);
-  void new_note();
-  void present_search();
+  virtual void set_search_text(const std::string & value);
+  virtual void present_note(const Note::Ptr & note);
+  virtual void new_note();
+  virtual void present_search();
 
   virtual void embed_widget(utils::EmbeddableWidget &);
   virtual void unembed_widget(utils::EmbeddableWidget &);
@@ -72,17 +67,32 @@ private:
   bool on_key_pressed(GdkEventKey *);
   bool is_foreground(utils::EmbeddableWidget &);
   utils::EmbeddableWidget *currently_embedded();
-  Gtk::Toolbar *make_toolbar();
+  Gtk::Box *make_toolbar();
   void on_embedded_name_changed(const std::string & name);
+  void on_entry_changed();
+  void on_entry_activated();
+  void entry_changed_timeout();
+  std::string get_search_text();
+  void update_toolbar(utils::EmbeddableWidget & widget);
+  void on_show_window_menu(Gtk::Button *button);
+  Gtk::Menu *make_window_menu(Gtk::Button *button, const std::vector<Gtk::MenuItem*> & items);
+  std::vector<Gtk::MenuItem*> & make_menu_items(std::vector<Gtk::MenuItem*> & items,
+                                                const std::vector<Glib::RefPtr<Gtk::Action> > & actions);
+  void on_main_window_actions_changed(Gtk::Menu **menu);
 
   NoteManager        &m_note_manager;
   SearchNotesWidget   m_search_notes_widget;
   Gtk::VBox           m_content_vbox;
   Gtk::VBox           m_embed_box;
-  Gtk::ToolButton    *m_all_notes_button;
+  Gtk::Button        *m_all_notes_button;
+  Gtk::SearchEntry    m_search_entry;
   std::list<utils::EmbeddableWidget*> m_embedded_widgets;
   bool                m_mapped;
   sigc::connection    m_current_embedded_name_slot;
+  utils::InterruptableTimeout *m_entry_changed_timeout;
+  Gtk::Menu          *m_window_menu_search;
+  Gtk::Menu          *m_window_menu_note;
+  Gtk::Menu          *m_window_menu_default;
 };
 
 
