@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012 Aurimas Cernius
+ * Copyright (C) 2012-2013 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,123 +20,53 @@
 
 #include "config.h"
 
-#include <boost/format.hpp>
+#include <boost/bind.hpp>
 #include <glibmm/i18n.h>
 #include <gtkmm/actiongroup.h>
 #include <sigc++/sigc++.h>
 
-#include "actionmanager.hpp"
+#include "iactionmanager.hpp"
 #include "addinmanager.hpp"
 #include "debug.hpp"
 #include "filesystemsyncserver.hpp"
-#include "gnote.hpp"
+#include "ignote.hpp"
 #include "gnotesyncclient.hpp"
 #include "notemanager.hpp"
 #include "preferences.hpp"
 #include "silentui.hpp"
 #include "syncmanager.hpp"
 #include "syncserviceaddin.hpp"
-#include "sharp/uuid.hpp"
 #include "sharp/xmlreader.hpp"
 
 
 namespace gnote {
 namespace sync {
 
-  namespace {
-
-    typedef GObject SyncHelper;
-    typedef GObjectClass SyncHelperClass;
-
-    G_DEFINE_TYPE(SyncHelper, sync_helper, G_TYPE_OBJECT)
-
-    void sync_helper_init(SyncHelper*)
-    {}
-
-    void sync_helper_class_init(SyncHelperClass * klass)
-    {
-      g_signal_new("delete-notes", G_TYPE_FROM_CLASS(klass),
-                   GSignalFlags(G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS),
-                   0, NULL, NULL, g_cclosure_marshal_VOID__POINTER,
-                   G_TYPE_NONE, 1, G_TYPE_POINTER, NULL);
-      g_signal_new("create-note", G_TYPE_FROM_CLASS(klass),
-                   GSignalFlags(G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS),
-                   0, NULL, NULL, g_cclosure_marshal_VOID__POINTER,
-                   G_TYPE_NONE, 1, G_TYPE_POINTER, NULL);
-      g_signal_new("update-note", G_TYPE_FROM_CLASS(klass),
-                   GSignalFlags(G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS),
-                   0, NULL, NULL, g_cclosure_marshal_generic,
-                   G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_POINTER, NULL);
-      g_signal_new("delete-note", G_TYPE_FROM_CLASS(klass),
-                   GSignalFlags(G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS),
-                   0, NULL, NULL, g_cclosure_marshal_VOID__POINTER,
-                   G_TYPE_NONE, 1, G_TYPE_POINTER, NULL);
-    }
-
-    GObject * sync_helper_new()
-    {
-      g_type_init();
-      return G_OBJECT(g_object_new(sync_helper_get_type(), NULL));
-    }
-
-    void sync_helper_delete_notes(GObject * helper, gpointer server)
-    {
-      gdk_threads_enter();
-      g_signal_emit_by_name(helper, "delete-notes", server);
-      gdk_threads_leave();
-    }
-
-    void sync_helper_create_note(GObject * helper, gpointer note_update)
-    {
-      gdk_threads_enter();
-      g_signal_emit_by_name(helper, "create-note", note_update);
-      gdk_threads_leave();
-    }
-
-    void sync_helper_update_note(GObject * helper, gpointer existing_note, gpointer note_update)
-    {
-      gdk_threads_enter();
-      g_signal_emit_by_name(helper, "update-note", existing_note, note_update);
-      gdk_threads_leave();
-    }
-
-    void sync_helper_delete_note(GObject * helper, gpointer existing_note)
-    {
-      gdk_threads_enter();
-      g_signal_emit_by_name(helper, "delete-note", existing_note);
-      gdk_threads_leave();
-    }
-
+  SyncManager::SyncManager(NoteManager & m)
+    : m_note_manager(m)
+    , m_state(IDLE)
+    , m_sync_thread(NULL)
+  {
   }
 
 
-  SyncManager::~SyncManager()
+  void SyncManager::init(NoteManager & m)
   {
-    g_object_unref(m_sync_helper);
+    SyncManager *manager = new SyncManager(m);
+    manager->_init(m);
   }
 
 
-  void SyncManager::init()
+  void SyncManager::_init(NoteManager & manager)
   {
-    SyncManager::obj()._init();
-  }
-
-
-  void SyncManager::_init()
-  {
-    m_sync_helper = sync_helper_new();
-    g_signal_connect(m_sync_helper, "delete-notes", G_CALLBACK(SyncManager::on_delete_notes), NULL);
-    g_signal_connect(m_sync_helper, "create-note", G_CALLBACK(SyncManager::on_create_note), NULL);
-    g_signal_connect(m_sync_helper, "update-note", G_CALLBACK(SyncManager::on_update_note), NULL);
-    g_signal_connect(m_sync_helper, "delete-note", G_CALLBACK(SyncManager::on_delete_note), NULL);
-    m_client = SyncClient::Ptr(new GnoteSyncClient);
+    m_client = SyncClient::Ptr(new GnoteSyncClient(manager));
     // Add a "Synchronize Notes" to Gnote's Application Menu
-    ActionManager & am(ActionManager::obj());
+    IActionManager & am(IActionManager::obj());
     am.add_app_action("sync-notes");
-    am.add_app_menu_item(ActionManager::APP_ACTION_MANAGE, 200, _("Synchronize Notes"), "app.sync-notes");
+    am.add_app_menu_item(IActionManager::APP_ACTION_MANAGE, 200, _("Synchronize Notes"), "app.sync-notes");
 
     // Initialize all the SyncServiceAddins
-    Gnote::obj().default_note_manager().get_addin_manager().initialize_sync_service_addins();
+    manager.get_addin_manager().initialize_sync_service_addins();
 
     Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->signal_changed()
       .connect(sigc::mem_fun(*this, &SyncManager::preferences_setting_changed));
@@ -166,14 +96,13 @@ namespace sync {
     if(m_sync_thread != NULL) {
       // A synchronization thread is already running
       // TODO: Start new sync if existing dlg is for finished sync
-      // TODO: ISyncUI-ize this somehow
-      if(m_sync_ui == Gnote::obj().sync_dialog()) {
-        Gnote::obj().sync_dialog()->present();
-      }
+      DBG_OUT("A synchronization thread is already running");
+      m_sync_ui->present_ui();
       return;
     }
 
     m_sync_ui = sync_ui;
+    DBG_OUT("Creating synchronization thread");
     m_sync_thread = Glib::Thread::create(sigc::mem_fun(*this, &SyncManager::synchronization_thread), false);
   }
 
@@ -185,7 +114,7 @@ namespace sync {
       finally() : addin(NULL){}
       ~finally()
       {
-        SyncManager::obj().m_sync_thread = NULL;
+        SyncManager::_obj().m_sync_thread = NULL;
         try {
           if(addin) {
             addin->post_sync_cleanup();
@@ -282,10 +211,6 @@ namespace sync {
             DBG_OUT("Sync: Early conflict detection for '%s'", iter->second.m_title.c_str());
             if(m_sync_ui != 0) {
               m_sync_ui->note_conflict_detected(note_mgr(), existingNote, iter->second, noteUpdateTitles);
-
-              // Suspend this thread while the GUI is presented to
-              // the user.
-              //syncThread.Suspend ();  TODO: findout what to do with this!!!
             }
           }
         }
@@ -325,10 +250,6 @@ namespace sync {
           // Note already exists locally, but has been modified since last sync; prompt user
           if(m_sync_ui != 0) {
             m_sync_ui->note_conflict_detected(note_mgr(), existingNote, iter->second, noteUpdateTitles);
-
-            // Suspend this thread while the GUI is presented to
-            // the user.
-            //syncThread.Suspend ();  TODO find out what to do with this !!!
           }
 
           // Note has been deleted or okay'd for overwrite
@@ -344,7 +265,8 @@ namespace sync {
       // delegate to run in the main gtk thread.
       // To be consistent, any exceptions in the delgate will be caught
       // and then rethrown in the synchronization thread.
-      sync_helper_delete_notes(m_sync_helper, &server);
+      utils::main_context_call(boost::bind(
+        sigc::mem_fun(*this, &SyncManager::delete_notes), server));
 
       // TODO: Add following updates to syncDialog treeview
 
@@ -481,7 +403,7 @@ namespace sync {
   {
     Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC);
     std::string sync_addin_id = settings->get_string(Preferences::SYNC_SELECTED_SERVICE_ADDIN);
-    ActionManager::obj().get_app_action("sync-notes")->set_enabled(sync_addin_id != "");
+    IActionManager::obj().get_app_action("sync-notes")->set_enabled(sync_addin_id != "");
 
     int timeoutPref = settings->get_int(Preferences::SYNC_AUTOSYNC_TIMEOUT);
     if(timeoutPref != m_autosync_timeout_pref_minutes) {
@@ -615,7 +537,7 @@ namespace sync {
     SyncServiceAddin *addin = NULL;
 
     std::list<SyncServiceAddin*> addins;
-    Gnote::obj().default_note_manager().get_addin_manager().get_sync_service_addins(addins);
+    m_note_manager.get_addin_manager().get_sync_service_addins(addins);
     for(std::list<SyncServiceAddin*>::iterator iter = addins.begin(); iter != addins.end(); ++iter) {
       if((*iter)->id() == sync_service_id) {
         addin = *iter;
@@ -633,7 +555,8 @@ namespace sync {
     // delegate to run in the main gtk thread.
     // To be consistent, any exceptions in the delgate will be caught
     // and then rethrown in the synchronization thread.
-    sync_helper_create_note(m_sync_helper, const_cast<NoteUpdate*>(&noteUpdate));
+    utils::main_context_call(boost::bind(
+      sigc::mem_fun(*this, &SyncManager::create_note), noteUpdate));
   }
 
 
@@ -643,7 +566,8 @@ namespace sync {
     // delegate to run in the main gtk thread.
     // To be consistent, any exceptions in the delgate will be caught
     // and then rethrown in the synchronization thread.
-    sync_helper_update_note(m_sync_helper, const_cast<Note::Ptr*>(&existingNote), const_cast<NoteUpdate*>(&noteUpdate));
+    utils::main_context_call(boost::bind(
+      sigc::mem_fun(*this, &SyncManager::update_note), existingNote, noteUpdate));
   }
 
 
@@ -653,7 +577,8 @@ namespace sync {
     // delegate to run in the main gtk thread.
     // To be consistent, any exceptions in the delgate will be caught
     // and then rethrown in the synchronization thread.
-    sync_helper_delete_note(m_sync_helper, const_cast<Note::Ptr*>(&existingNote));
+    utils::main_context_call(boost::bind(
+      sigc::mem_fun(*this, &SyncManager::delete_note), existingNote));
   }
 
 
@@ -682,7 +607,7 @@ namespace sync {
 
   NoteManager & SyncManager::note_mgr()
   {
-    return Gnote::obj().default_note_manager();
+    return m_note_manager;
   }
 
 
@@ -732,24 +657,23 @@ namespace sync {
   }
 
 
-  void SyncManager::on_delete_notes(GObject*, gpointer serv, gpointer)
+  void SyncManager::delete_notes(const SyncServer::Ptr & server)
   {
     try {
-      SyncServer::Ptr & server = *static_cast<SyncServer::Ptr*>(serv);
       // Make list of all local notes
-      std::list<Note::Ptr> localNotes = SyncManager::obj().note_mgr().get_notes();
+      std::list<Note::Ptr> localNotes = note_mgr().get_notes();
 
       // Get all notes currently on server
       std::list<std::string> serverNotes = server->get_all_note_uuids();
 
       // Delete notes locally that have been deleted on the server
       for(std::list<Note::Ptr>::iterator iter = localNotes.begin(); iter != localNotes.end(); ++iter) {
-	if(SyncManager::obj().m_client->get_revision(*iter) != -1
+	if(SyncManager::_obj().m_client->get_revision(*iter) != -1
 	   && std::find(serverNotes.begin(), serverNotes.end(), (*iter)->id()) == serverNotes.end()) {
-	  if(SyncManager::obj().m_sync_ui != 0) {
-	    SyncManager::obj().m_sync_ui->note_synchronized((*iter)->get_title(), DELETE_FROM_CLIENT);
+	  if(m_sync_ui != 0) {
+	    m_sync_ui->note_synchronized((*iter)->get_title(), DELETE_FROM_CLIENT);
 	  }
-	  SyncManager::obj().note_mgr().delete_note(*iter);
+	  note_mgr().delete_note(*iter);
 	}
       }
     }
@@ -762,12 +686,11 @@ namespace sync {
   }
 
 
-  void SyncManager::on_create_note(GObject*, gpointer note_update, gpointer)
+  void SyncManager::create_note(const NoteUpdate & noteUpdate)
   {
     try {
-      NoteUpdate & noteUpdate = *static_cast<NoteUpdate*>(note_update);
-      Note::Ptr existingNote = SyncManager::obj().note_mgr().create_with_guid(noteUpdate.m_title, noteUpdate.m_uuid);
-      SyncManager::obj().update_local_note(existingNote, noteUpdate, DOWNLOAD_NEW);
+      Note::Ptr existingNote = note_mgr().create_with_guid(noteUpdate.m_title, noteUpdate.m_uuid);
+      update_local_note(existingNote, noteUpdate, DOWNLOAD_NEW);
     }
     catch(std::exception & e) {
       DBG_OUT("Exception caught in %s: %s\n", __func__, e.what());
@@ -778,12 +701,10 @@ namespace sync {
   }
 
 
-  void SyncManager::on_update_note(GObject*, gpointer existing_note, gpointer note_update, gpointer)
+  void SyncManager::update_note(const Note::Ptr & existingNote, const NoteUpdate & noteUpdate)
   {
     try {
-      Note::Ptr *existingNote = static_cast<Note::Ptr*>(existing_note);
-      NoteUpdate & noteUpdate = *static_cast<NoteUpdate*>(note_update);
-      SyncManager::obj().update_local_note(*existingNote, noteUpdate, DOWNLOAD_MODIFIED);
+      update_local_note(existingNote, noteUpdate, DOWNLOAD_MODIFIED);
     }
     catch(std::exception & e) {
       DBG_OUT("Exception caught in %s: %s\n", __func__, e.what());
@@ -794,11 +715,10 @@ namespace sync {
   }
 
 
-  void SyncManager::on_delete_note(GObject*, gpointer existing_note, gpointer)
+  void SyncManager::delete_note(const Note::Ptr & existingNote)
   {
     try {
-      Note::Ptr *existingNote = static_cast<Note::Ptr*>(existing_note);
-      SyncManager::obj().note_mgr().delete_note(*existingNote);
+      note_mgr().delete_note(existingNote);
     }
     catch(std::exception & e) {
       DBG_OUT("Exception caught in %s: %s\n", __func__, e.what());
@@ -811,30 +731,9 @@ namespace sync {
 
   void SyncManager::note_save(const Note::Ptr & note)
   {
-    gdk_threads_enter();
-    note->save();
-    gdk_threads_leave();
+    utils::main_context_call(sigc::mem_fun(*note, &Note::save));
   }
 
 
-  SyncLockInfo::SyncLockInfo()
-    : client_id(Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->get_string(Preferences::SYNC_CLIENT_ID))
-    , transaction_id(sharp::uuid().string())
-    , renew_count(0)
-    , duration(0, 2, 0) // default of 2 minutes
-    , revision(0)
-  {
-  }
-
-
-  std::string SyncLockInfo::hash_string()
-  {
-    return str(boost::format("%1%-%2%-%3%-%4%-%5%") % transaction_id % client_id % renew_count % duration.string() % revision);
-  }
-
-
-  SyncServer::~SyncServer()
-  {}
-
 }
 }
